@@ -4,7 +4,7 @@
 jtramoseats <- function(series, spec = c("RSAfull", "RSA0", "RSA1", "RSA2", "RSA3", "RSA4", "RSA5"),
                        userdefined = NULL){
   if (!is.ts(series)) {
-    stop("series must be a time series")
+    stop("The series must be a time series")
   }
   UseMethod("jtramoseats", spec)
 }
@@ -14,7 +14,7 @@ jtramoseats.SA_spec <- function(series, spec,
 
   if (!inherits(spec, "TRAMO_SEATS"))
     stop("use only with c(\"SA_spec\",\"TRAMO_SEATS\") class object")
-  # create the java objects
+  # To create the Java objects
   jrspec <- .jcall("jdr/spec/tramoseats/TramoSeatsSpec", "Ljdr/spec/tramoseats/TramoSeatsSpec;", "of", "RSA0")
   jdictionary <- spec_TRAMO_r2jd(spec,jrspec)
   specSeats_r2jd(spec,jrspec)
@@ -28,7 +28,7 @@ jtramoseats.SA_spec <- function(series, spec,
 jtramoseats.character <- function(series, spec = c("RSAfull", "RSA0", "RSA1", "RSA2", "RSA3", "RSA4", "RSA5"),
                                  userdefined = NULL){
   spec <- match.arg(spec)
-  # create the java objects
+  # To create the Java objects
   jrspec <- .jcall("jdr/spec/tramoseats/TramoSeatsSpec", "Ljdr/spec/tramoseats/TramoSeatsSpec;", "of", spec)
   jspec <- .jcall(jrspec, "Lec/satoolkit/tramoseats/TramoSeatsSpecification;", "getCore")
   jdictionary <- .jnew("jdr/spec/ts/Utility$Dictionary")
